summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
Diffstat (limited to 'tools')
-rw-r--r--tools/build_esp32s2.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/build_esp32s2.py b/tools/build_esp32s2.py
index 6580b6562..0ef05023c 100644
--- a/tools/build_esp32s2.py
+++ b/tools/build_esp32s2.py
@@ -27,8 +27,8 @@ def filter_with_input(mylist):
# Build all examples if not specified
all_examples = []
for entry in os.scandir("examples/device"):
- # Only includes example with CMakeLists.txt for esp32s
- if entry.is_dir() and os.path.exists(entry.path + "/sdkconfig.defaults"):
+ # Only includes example with CMakeLists.txt for esp32s, and skip board_test to speed up ci
+ if entry.is_dir() and os.path.exists(entry.path + "/sdkconfig.defaults") and entry.name != 'board_test':
all_examples.append(entry.name)
filter_with_input(all_examples)
all_examples.sort()